sqltriples.Query.CountableResults

Package sqltriples :: Module Query :: Class CountableResults |
[show private | hide private]
[frames | no frames]

## Class CountableResults

    AbstractQuery --+
                    |
                Query --+
                        |
                  Results --+
                            |
                           CountableResults

A class representing a count of some results.

Method Summary
| `__getitem__(self, i)`
| `__len__(self)`
| `__repr__(self)`
| `get_query(self, index)`
| ``get_subquery`(self, parent_columns, parent_index, index, match_first, match_parent, match_child)` Make a subquery for this object using the given 'parent_columns' (indicating the columns which connect with this object's exposed columns), a 'parent_index' (indicating the table index used in the parent query, within which the returned query clause shall be employed), and the current table 'index'.
| `get_value(self)`
Inherited from Results
| ``__init__`(self, store, pattern, expression, functions, ordering, order_by, limit, partial)` Initialise the results object with the given 'store', 'pattern', optional 'expression', optional 'ordering' and 'order_by' descriptions and optional 'limit' criteria.

Class Variable Summary
`list` | `exposed_columns` = `[('subject', 'subject_type'), ('predic...`
Inherited from AbstractQuery
`list` | `table_columns` = `[('subject', 'subject_type', 0), ('predi...`

Method Details

### get_subquery(self, parent_columns, parent_index, index, match_first=0, match_parent=0, match_child=0) Make a subquery for this object using the given 'parent_columns' (indicating the columns which connect with this object's exposed columns), a 'parent_index' (indicating the table index used in the parent query, within which the returned query clause shall be employed), and the current table 'index'. Return a query clause, associated values, and an updated table index (as a 3-tuple). Overrides: `sqltriples.Query.Query.get_subquery` (inherited documentation)

Class Variable Details

    ### exposed_columns Type: `list` Value:
        [('subject', 'subject_type'), ('predicate', None), ('object', 'object_\
        type')]

Generated by Epydoc 2.1 on Sat Sep 30 00:54:36 2006 | http://epydoc.sf.net